pub unsafe extern "C" fn duckdb_copy_function_bind_get_client_context(
info: duckdb_copy_function_bind_info,
) -> duckdb_client_contextExpand description
Retrieves the client context of the current connection binding the COPY ... TO function.
Must be destroyed with duckdb_destroy_client_context
@param info The bind info provided to the bind function @return The client context.