duckdb_copy_function_bind_get_column_count

Function duckdb_copy_function_bind_get_column_count 

pub unsafe extern "C" fn duckdb_copy_function_bind_get_column_count(
    info: duckdb_copy_function_bind_info,
) -> idx_t
Retrieves the number of columns that will be provided to the COPY ... TO function.

@param info The bind info provided to the bind function @return The number of columns.