pub unsafe extern "C" fn duckdb_copy_function_bind_get_extra_info(
info: duckdb_copy_function_bind_info,
) -> *mut c_voidExpand description
Retrieves the extra info pointer of the copy function.
@param info The bind info provided to the bind function @return The extra info pointer.