duckdb_copy_function_bind_set_bind_data

Function duckdb_copy_function_bind_set_bind_data 

pub unsafe extern "C" fn duckdb_copy_function_bind_set_bind_data(
    info: duckdb_copy_function_bind_info,
    bind_data: *mut c_void,
    destructor: duckdb_delete_callback_t,
)
Sets the bind data of the copy function, to be provided to the init, sink and finalize functions.

@param info The bind info provided to the bind function @param bind_data The bind data pointer @param destructor A destructor function to call to destroy the bind data