pub unsafe extern "C" fn duckdb_copy_function_global_init_get_client_context(
info: duckdb_copy_function_global_init_info,
) -> duckdb_client_contextExpand description
Retrieves the client context of the current connection initializing the COPY ... TO function.
Must be destroyed with duckdb_destroy_client_context
@param info The init info provided to the init function @return The client context.