pub unsafe extern "C" fn duckdb_copy_function_global_init_get_extra_info(
info: duckdb_copy_function_global_init_info,
) -> *mut c_voidExpand description
Retrieves the extra info pointer of the copy function.
@param info The init info provided to the init function @return The extra info pointer.