duckdb_copy_function_global_init_get_file_path

Function duckdb_copy_function_global_init_get_file_path 

pub unsafe extern "C" fn duckdb_copy_function_global_init_get_file_path(
    info: duckdb_copy_function_global_init_info,
) -> *const c_char
Retrieves the file path provided to the COPY ... TO function.

Lives for the duration of the initialization callback, must not be destroyed.

@param info The init info provided to the init function @return The file path.