duckdb_copy_function_global_init_set_global_state

Function duckdb_copy_function_global_init_set_global_state 

pub unsafe extern "C" fn duckdb_copy_function_global_init_set_global_state(
    info: duckdb_copy_function_global_init_info,
    global_state: *mut c_void,
    destructor: duckdb_delete_callback_t,
)
Sets the global state of the copy function, to be provided to all subsequent local init, sink and finalize functions.

@param info The init info provided to the init function @param global_state The global state pointer @param destructor A destructor function to call to destroy the global state