pub unsafe extern "C" fn duckdb_destroy_file_open_options(
options: *mut duckdb_file_open_options,
)Expand description
Destroys the given file open options instance. @param options The file open options instance to destroy.
pub unsafe extern "C" fn duckdb_destroy_file_open_options(
options: *mut duckdb_file_open_options,
)Destroys the given file open options instance. @param options The file open options instance to destroy.