pub unsafe extern "C" fn duckdb_scalar_function_init_get_client_context(
info: duckdb_init_info,
out_context: *mut duckdb_client_context,
)Expand description
Retrieves the client context of the init info of a scalar function.
@param info The init info object of the scalar function.
@param out_context The client context of the init info. Must be destroyed with duckdb_destroy_client_context.