pub unsafe extern "C" fn duckdb_table_function_bind_get_result_column_count(
info: duckdb_bind_info,
) -> idx_tExpand description
Retrieves the number of result columns of a table function.
If the table function is used in a COPY ... FROM statement, this can be used to retrieve the number of columns in the
target table at the start of the bind callback.
@param info The bind info provided to the bind function @return The number of result columns.