pub unsafe extern "C" fn duckdb_table_function_bind_get_result_column_name(
info: duckdb_bind_info,
col_idx: idx_t,
) -> *const c_charExpand description
Retrieves the name of a result column of a table function.
If the table function is used in a COPY ... FROM statement, this can be used to retrieve the names of the columns in
the target table at the start of the bind callback.
The result is valid for the duration of the bind callback or until the next call to duckdb_bind_add_result_column, so
it must not be destroyed.
@param info The bind info provided to the bind function @param col_idx The index of the result column to retrieve the name for @return The name of the result column.