duckdb_unsafe_vector_assign_string_element_len

Function duckdb_unsafe_vector_assign_string_element_len 

pub unsafe extern "C" fn duckdb_unsafe_vector_assign_string_element_len(
    vector: duckdb_vector,
    index: idx_t,
    str_: *const c_char,
    str_len: idx_t,
)
Assigns a string element in the vector at the specified location without UTF-8 validation. The caller is responsible for ensuring the input is valid UTF-8. Use duckdb_valid_utf8_check to validate strings before calling this function if needed. If the input is known to be valid UTF-8, this function can be called directly for better performance, avoiding the overhead of redundant validation.

@param vector The vector to alter @param index The row position in the vector to assign the string to @param str The string @param str_len The length of the string (in bytes)