pub unsafe extern "C" fn duckdb_vector_assign_string_element(
vector: duckdb_vector,
index: idx_t,
str_: *const c_char,
)Expand description
Assigns a string element in the vector at the specified location. For VARCHAR vectors, the input is validated as UTF-8; if invalid, a NULL value is assigned at that index.
Superseded by duckdb_unsafe_vector_assign_string_element_len, optionally combined with duckdb_valid_utf8_check.
@param vector The vector to alter @param index The row position in the vector to assign the string to @param str The null-terminated string