pub type duckdb_config_option = *mut _duckdb_config_option;Expand description
! A custom configuration option instance. Used to register custom options that can be set on a duckdb_config.
! or by the user in SQL using SET <option_name> = <value>.
pub type duckdb_config_option = *mut _duckdb_config_option;! A custom configuration option instance. Used to register custom options that can be set on a duckdb_config.
! or by the user in SQL using SET <option_name> = <value>.