pub type duckdb_config_option_scope = c_uint;Expand description
! An enum over DuckDB’s configuration option scopes. ! This enum can be used to specify the default scope when creating a custom configuration option, ! but it is also be used to determine the scope in which a configuration option is set when it is ! changed or retrieved.