pub unsafe extern "C" fn duckdb_copy_function_bind_get_options(
info: duckdb_copy_function_bind_info,
) -> duckdb_valueExpand description
Retrieves all values for the given options provided to the COPY ... TO function.
@param info The bind info provided to the bind function
@return A STRUCT value containing all options as fields. Must be destroyed with duckdb_destroy_value.