pub unsafe extern "C" fn duckdb_copy_function_finalize_get_client_context(
info: duckdb_copy_function_finalize_info,
) -> duckdb_client_contextExpand description
Retrieves the client context of the current connection during the finalize-phase of the COPY ... TO function.
Must be destroyed with duckdb_destroy_client_context
@param info The finalize info provided to the finalize function @return The client context.