pub unsafe extern "C" fn duckdb_copy_function_set_extra_info(
copy_function: duckdb_copy_function,
extra_info: *mut c_void,
destructor: duckdb_delete_callback_t,
)Expand description
Sets the extra info pointer of the copy function, which can be used to store arbitrary data.
@param copy_function The copy function @param extra_info The extra info pointer @param destructor A destructor function to call to destroy the extra info