pub unsafe extern "C" fn duckdb_copy_function_sink_get_client_context(
info: duckdb_copy_function_sink_info,
) -> duckdb_client_contextExpand description
Retrieves the client context of the current connection during the sink-phase of the COPY ... TO function.
Must be destroyed with duckdb_destroy_client_context
@param info The sink info provided to the sink function @return The client context.