pub unsafe extern "C" fn duckdb_scalar_function_init_set_state(
info: duckdb_init_info,
state: *mut c_void,
destroy: duckdb_delete_callback_t,
)Expand description
Sets the state pointer in the init info of the scalar function.
@param info The init info object. @param state The state pointer. @param destroy The callback to destroy the state (if any).